==> formide-cli-0.1.3.tgz: package/lib/formide/publish.js <==
/*
 *	    ____  ____  _____   ____________
 *	   / __ / __ /  _/ | / /_  __/ __
 *	  / /_/ / /_/ // //  |/ / / / / /_/ /
 *	 / ____/ _, _// // /|  / / / / _, _/
 *	/_/   /_/ |_/___/_/ |_/ /_/ /_/ |_|
 *
 */

/*
 *	Publish an app to the Formide App Store
 */

var fs 				= require('fs');
var	path			= require('path');
var archiver 		= require('archiver');
var FormideProject 	= require('./project.js');
var Task 			= require('./task.js').Task;
var FormideLogin 	= require('./login.js').FormideTask;
var FormideUtils 	= require('./utils.js');
var request			= require('request');

var FormideTask 	= function() {};

FormideTask.prototype = new Task();

FormideTask.prototype.run = function( formide, callback )
{
	var project = null;
	this.formide = formide;

	try
	{
		project = FormideProject.load();
	}
	catch( e )
	{
		this.formide.fail( e.message );
	}

	var self = this;

	var login = new FormideLogin();

	login.get( formide, function( jar )
	{
		var homeDir = process.env.HOME || process.env.USERPROFILE || process.env.HOMEPATH;
		var TEMP_FILENAME = path.join(homeDir, '.formide', project.get('identifier') + '.zip');
		var zip = fs.createWriteStream(TEMP_FILENAME);
		var archive = archiver('zip');

		archive.pipe(zip);

		archive.bulk([
			{
				expand: true,
				cwd: './',
				src: ['**']
			}
		]);

		archive.finalize( function( err, bytes )
		{
			if( err )
			{
				return formide.fail('Error uploading: ' + err);
			}
		});

		zip.on('close', function()
		{
			console.log('\nUploading app...'.bold.green);

			var csrftoken = '';
			csrftoken = FormideUtils.retrieveCsrfToken(jar);
			var url = formide.FORMIDE_API + formide.API_APPS + '/upload/' + project.get('app_id');

			console.log( url );

			fs.createReadStream( TEMP_FILENAME ).pipe(request.post( url ) );
		});
	});
};

exports.FormideTask = FormideTask;

==> formide-cli-0.1.12.tgz: package/lib/formide/publish.js <==
/*
 *	    ____  ____  _____   ____________
 *	   / __ / __ /  _/ | / /_  __/ __
 *	  / /_/ / /_/ // //  |/ / / / / /_/ /
 *	 / ____/ _, _// // /|  / / / / _, _/
 *	/_/   /_/ |_/___/_/ |_/ /_/ /_/ |_|
 *
 */

/*
 *	Publish an app to the Formide App Store
 */

var fs 				= require('fs');
var	path			= require('path');
var archiver 		= require('archiver');
var FormideProject 	= require('./project.js');
var Task 			= require('./task.js').Task;
var FormideLogin 	= require('./login.js').FormideTask;
var FormideUtils 	= require('./utils.js');
var request			= require('request');

var FormideTask 	= function() {};

FormideTask.prototype = new Task();

FormideTask.prototype.run = function( formide, callback )
{
	var project = null;
	this.formide = formide;

	try
	{
		project = FormideProject.load();
	}
	catch( e )
	{
		this.formide.fail( e.message );
	}

	var self = this;

	var login = new FormideLogin();

	login.get( formide, function( jar )
	{
		var homeDir = process.env.HOME || process.env.USERPROFILE || process.env.HOMEPATH;
		var TEMP_FILENAME = path.join(homeDir, '.formide', project.get('identifier') + '.zip');
		var zip = fs.createWriteStream(TEMP_FILENAME);
		var archive = archiver('zip');

		archive.pipe(zip);

		archive.bulk([
			{
				expand: true,
				cwd: './',
				src: ['**']
			}
		]);

		archive.finalize( function( err, bytes )
		{
			if( err )
			{
				return formide.fail('Error uploading: ' + err);
			}
		});

		zip.on('close', function()
		{
			console.log('\nUploading app...'.bold.green);

			var csrftoken = '';
			csrftoken = FormideUtils.retrieveCsrfToken(jar);
			var url = formide.FORMIDE_API + formide.API_APPS + '/upload/' + project.get('app_id');

			console.log( url );

			var upload = fs.createReadStream( TEMP_FILENAME ).pipe(request.post( url ) );

			upload.on('end', function( err )
			{
				console.log('\nFinished uploading'.bold.green);
				console.log( ('Go to https://apps.formide.com/apps/'+project.get('app_id')+' to test or publish your app').yellow );
			});
		});
	});
};

exports.FormideTask = FormideTask;
